import React, { HTMLAttributes, MutableRefObject } from 'react';

/**
 * Properties for the `SmartInput` component.
 */
interface SmartInputProps<P> extends Omit<HTMLAttributes<HTMLElement>, 'onChange'> {
    /**
     * The path of the model to use for completions, e.g. "my-org/my-input". If not provided, a sample completion will be displayed.
     */
    model?: string;
    /**
     * The ID of the user using the input. Providing this helps the model learn a particular user's style,
     * including if they prefer not to use completions at all.
     */
    user?: string;
    /**
     * Data that will help the model generate better completions.
     * Pass anything that you think is relevant to making the completions better or more personalized.
     * For example, it could be an English sentence description of what's happening in your app or a JSON.stringify'd object
     * of useful key/value pairs.
     */
    context?: string;
    /**
     * A ref to the underlying contenteditable div. This can be used to focus the editor, select text, etc.
     */
    /**
     * The controlled value of the input.
     */
    value: string;
    /**
     * Called whenever the value of the input changes. Use this to update the controlled `value` property.
     */
    onChange: (newValue: string) => void;
    /**
     * Renders text the user has input.
     */
    renderText: (props: any) => React.ReactElement<any, any>;
    /**
     * Renders suggested, tab-completable text.
     */
    renderCompletion: (props: any) => React.ReactElement<any, any>;
    /**
     * Renders the placeholder text when the input value is empty.
     * If not provided, the placeholder will be rendered with a regular, low opacity text node.
     */
    renderPlaceholder?: (props: any) => React.ReactElement<any, any>;
    /**
     * A ref to the underlying contenteditable wrapper element. This can be used to focus the editor, select text, etc.
     */
    editorRef?: MutableRefObject<any>;
    /**
     * If true, the input value may contain newline characters. If false, the input value will be foreced to stay a single line.
     */
    multiline?: boolean;
    /**
     * Called when the input loses focus.
     */
    onBlur?: React.FocusEventHandler<HTMLElement>;
    /**
     * Called when the input gains focus.
     */
    onFocus?: React.FocusEventHandler<HTMLElement>;
    /**
     * Called when a key is pressed while the input is focused.
     */
    onKeyDown?: React.KeyboardEventHandler<HTMLElement>;
    /**
     * The value to display when the input is empty. If not provided, no placeholder is displayed.
     */
    placeholder?: string;
    /**
     * Whether to allow the user to edit the input. If false, the input will be read-only.
     */
    disabled?: boolean;
    /**
     * Whether or not to request completions. If true, the input will not request completions and will behave like a normal input.
     * It will still collect data and learn to generate completions.
     */
    safeMode?: boolean;
    /**
     * The CSS styles to apply to the contenteditable div container.
     */
    style?: React.CSSProperties;
    /**
     * The CSS class name to apply to the contenteditable div container.
     */
    className?: string;
    /**
     * If provided, this function will be called to generate a completion instead of fetching one from the model.
     */
    getCompletion?: (text: string) => string;
    /**
     * If trye, the component will make requests to localhost instead of default API URL.
     */
    dev?: boolean;
    /**
     * The provided, the element to use for the container. Defaults to a `<div>`.
     */
    container?: React.ElementType<P>;
    /**
     * Props to pass to the container element, when one is provided.
     */
    containerProps?: P;
}
/**
 * A text input that provides intelligent, tab-completable completions based on the text that has already been entered.
 * Due to the limitations of `<input>` and `<textarea>` elements, this component renders a `<div contenteditable="true">` instead.
 */
declare function SmartInput<P>(p: SmartInputProps<P>): JSX.Element;

declare function useSmartInput(arg: {
    model: string;
    context?: any;
    apiUrl?: string;
}): (e: React.ChangeEvent<HTMLInputElement>) => void;

export { SmartInput, useSmartInput };
